
# Type: coexists with


holds between two entities that are co-located in the same aggregate object, process, or spatio-temporal region

URI: [biolink:coexists_with](https://w3id.org/biolink/vocab/coexists_with)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [colocalizes with](colocalizes_with.md)
 *  [in cell population with](in_cell_population_with.md)
 *  [in complex with](in_complex_with.md)
 *  [in pathway with](in_pathway_with.md)

## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | SEMMEDDB:COEXISTS_WITH |
| **In Subsets:** | | translator_minimal |

